pub struct Window {
main_stack: TemplateChild<Stack>,
loading: TemplateChild<WindowHandle>,
login: TemplateChild<Login>,
error_page: TemplateChild<ErrorPage>,
pub(super) session_view: TemplateChild<SessionView>,
toast_overlay: TemplateChild<ToastOverlay>,
compact: Cell<bool>,
session_selection: FixedSelection,
pub(super) account_switcher: AccountSwitcherPopover,
}Fields
main_stack: TemplateChild<Stack>loading: TemplateChild<WindowHandle>login: TemplateChild<Login>error_page: TemplateChild<ErrorPage>session_view: TemplateChild<SessionView>toast_overlay: TemplateChild<ToastOverlay>compact: Cell<bool>Whether the window should be in compact view.
It means that the horizontal size is not large enough to hold all the content.
session_selection: FixedSelectionThe selection of the logged-in sessions.
The one that is selected being the one that is visible.
account_switcher: AccountSwitcherPopoverThe account switcher popover.
Implementations
Sourceimpl Window
impl Window
Sourcefn register_type()
fn register_type()
Registers the type only once.
Sourceimpl Window
impl Window
Sourcefn set_compact(&self, compact: bool)
fn set_compact(&self, compact: bool)
Set whether the window should be in compact view.
Sourcefn finish_session_selection_init(&self)
fn finish_session_selection_init(&self)
Finish the initialization of the session selection, when the session list is ready.
Sourcefn select_first_session(&self)
fn select_first_session(&self)
Select the first session in the session list.
To be used when there is no current selection.
Sourcefn load_window_size(&self)
fn load_window_size(&self)
Load the window size from the settings.
Sourcefn save_window_size(&self) -> Result<(), BoolError>
fn save_window_size(&self) -> Result<(), BoolError>
Save the current window size to the settings.
Sourcefn restore_current_visible_session(&self)
fn restore_current_visible_session(&self)
Restore the currently visible session from the settings.
Sourcefn save_current_visible_session(&self) -> Result<(), BoolError>
fn save_current_visible_session(&self) -> Result<(), BoolError>
Save the currently visible session to the settings.
Sourcepub(super) fn visible_page(&self) -> WindowPage
pub(super) fn visible_page(&self) -> WindowPage
The visible page of the window.
Sourcepub(super) fn current_session_id(&self) -> Option<String>
pub(super) fn current_session_id(&self) -> Option<String>
The ID of the currently visible session, if any.
Sourcepub(super) fn set_current_session_by_id(&self, session_id: &str) -> bool
pub(super) fn set_current_session_by_id(&self, session_id: &str) -> bool
Set the current session by its ID.
Returns true if the session was set as the current session.
Sourcefn update_selected_session(&self)
fn update_selected_session(&self)
Update the selected session in the session view.
Sourcepub(super) fn show_session(&self)
pub(super) fn show_session(&self)
Show the selected session.
The displayed view will change according to the current session.
Sourcefn set_visible_page(&self, page: WindowPage)
fn set_visible_page(&self, page: WindowPage)
Set the visible page of the window.
Sourcepub(super) fn show_secret_error(&self, message: &str)
pub(super) fn show_secret_error(&self, message: &str)
Open the error page and display the given secret error message.
Sourcefn open_account_settings(&self, session_id: &str)
fn open_account_settings(&self, session_id: &str)
Open the account settings for the session with the given ID.